# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/code_template.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import file_pb2 as eolymp_dot_executor_dot_file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/atlas/code_template.proto\x12\x0c\x65olymp.atlas\x1a\x1a\x65olymp/executor/file.proto\"\x8d\x01\n\x08Template\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x03 \x01(\t\x12\x0e\n\x06secret\x18\x04 \x01(\x08\x12\x0e\n\x06source\x18\n \x01(\t\x12\x0e\n\x06header\x18\x0b \x01(\t\x12\x0e\n\x06\x66ooter\x18\x0c \x01(\t\x12$\n\x05\x66iles\x18\x1e \x03(\x0b\x32\x15.eolymp.executor.FileB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.code_template_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_TEMPLATE']._serialized_start=79
  _globals['_TEMPLATE']._serialized_end=220
# @@protoc_insertion_point(module_scope)
